pub struct Lambda<I, O> { /* private fields */ }Expand description
Wraps an async or sync closure so it can act as a Runnable<I, O>.
Implementations
Sourceimpl<I, O> Lambda<I, O>
impl<I, O> Lambda<I, O>
Sourcepub fn from_async<F, Fut>(f: F) -> Self
pub fn from_async<F, Fut>(f: F) -> Self
Build from an async closure that ignores the config.
Sourcepub fn from_async_with_config<F, Fut>(f: F) -> Self
pub fn from_async_with_config<F, Fut>(f: F) -> Self
Build from an async closure that uses the config.