pub struct Extensions { /* private fields */ }Expand description
A typed map indexed by TypeId. Each T: Any + Send + Sync + 'static
can have at most one value stored.
Implementations
Sourceimpl Extensions
impl Extensions
Sourcepub fn insert<T: Any + Send + Sync + 'static>(&mut self, value: T) -> Option<T>
pub fn insert<T: Any + Send + Sync + 'static>(&mut self, value: T) -> Option<T>
Insert a value. Returns the previous value of the same type, if any.
Sourcepub fn get<T: Any + Send + Sync + 'static>(&self) -> Option<&T>
pub fn get<T: Any + Send + Sync + 'static>(&self) -> Option<&T>
Get a reference to a stored value of type T.
Sourcepub fn get_mut<T: Any + Send + Sync + 'static>(&mut self) -> Option<&mut T>
pub fn get_mut<T: Any + Send + Sync + 'static>(&mut self) -> Option<&mut T>
Get a mutable reference to a stored value of type T.
Sourcepub fn remove<T: Any + Send + Sync + 'static>(&mut self) -> Option<T>
pub fn remove<T: Any + Send + Sync + 'static>(&mut self) -> Option<T>
Remove and return the stored value of type T.