pub trait ExampleSelector<E>: Send + Sync{
// Required method
fn select(&self, input: &str, examples: &[E]) -> Result<Vec<E>>;
}Expand description
Strategy for choosing which examples to include in a few-shot prompt.
Implementations receive an input value (typed) and the full pool of
available examples, and return the examples to use, in render order.